==> navit_0.5.0+dfsg.1.orig.tar.gz: navit-0.5.0+dfsg.1/config.h.cmake <==
#cmakedefine USE_NATIVE_LANGUAGE_SUPPORT 1
#cmakedefine HAVE_MALLOC_H 1
#cmakedefine HAVE_SYS_MOUNT_H 1
#cmakedefine HAVE_STDINT_H 1
#cmakedefine HAVE_API_ANDROID 1
#cmakedefine HAVE_API_WIN32_BASE 1
#cmakedefine HAVE_API_WIN32 1
#cmakedefine HAVE_API_WIN32_CE 1
#cmakedefine HAVE_GLIB 1
#cmakedefine HAVE_GMODULE 1
#cmakedefine HAVE_GETCWD 1
#define CACHE_SIZE ${CACHE_SIZE}
#cmakedefine AVOID_FLOAT 1
#cmakedefine AVOID_UNALIGNED 1
#cmakedefine USE_LIBGNUINTL 1
#cmakedefine HAVE_BYTESWAP_H 1
/* Versions */
#cmakedefine PACKAGE_VERSION "@PACKAGE_VERSION@"
#cmakedefine PACKAGE_NAME "@PACKAGE_NAME@"
#cmakedefine PACKAGE "@PACKAGE@"
#cmakedefine LOCALEDIR "@LOCALEDIR@"

#cmakedefine HAVE_LIBCRYPTO 1

#cmakedefine HAVE_ZLIB 1

#cmakedefine USE_ROUTING 1

#cmakedefine HAVE_GTK2 1

#cmakedefine HAVE_FONTCONFIG 1

#cmakedefine USE_PLUGINS 1

#cmakedefine SDL_TTF 1

#cmakedefine SDL_IMAGE 1

#cmakedefine HAVE_QT_SVG 1

#cmakedefine HAVE_UNISTD_H 1

#cmakedefine DBUS_USE_SYSTEM_BUS 1

#cmakedefine HAVE_SOCKET 1
#cmakedefine HAVE_SNPRINTF 1
#cmakedefine HAVE_DECL__SNPRINTF 1

#cmakedefine HAVE_WINSOCK 1

#cmakedefine HAVE_MEMALIGN 1

#cmakedefine HAVE_POSIX_MEMALIGN 1

#cmakedefine HAVE_VALLOC 1

#cmakedefine HAVE_LC_MESSAGES 1

#cmakedefine HAVE_SYS_TIME_H 1

#cmakedefine HAVE_POPEN 1

#cmakedefine HAVE_GETOPT_H 1
#cmakedefine HAVE_GETTIMEOFDAY 1

#cmakedefine HAVE__ATOI64 1

#cmakedefine HAVE_STRING_H 1

#cmakedefine EZXML_NOMMAP 0

#cmakedefine HAVE_STPCPY 1

#cmakedefine HAVE_SBRK 1

#cmakedefine HAVE_PRAGMA_PACK 1

#cmakedefine HAVE_GETDELIM 1

#cmakedefine HAVE_GETLINE 1

#cmakedefine HAVE_FSYNC 1

#cmakedefine HAVE_ENDIAN_H 1

#cmakedefine HAVE_FREEIMAGE 1

#cmakedefine USE_OPENGLES 1

#cmakedefine USE_OPENGLES2 1

#cmakedefine HAVE_SHMEM 1

#cmakedefine HAVE_IMLIB2 1

==> navit_0.5.1+dfsg.1.orig.tar.gz: navit-0.5.1/config.h.cmake <==
#cmakedefine USE_NATIVE_LANGUAGE_SUPPORT 1
#cmakedefine HAVE_MALLOC_H 1
#cmakedefine HAVE_SYS_MOUNT_H 1
#cmakedefine HAVE_STDINT_H 1
#cmakedefine HAVE_API_ANDROID 1
#cmakedefine HAVE_API_WIN32_BASE 1
#cmakedefine HAVE_API_WIN32 1
#cmakedefine HAVE_API_WIN32_CE 1
#cmakedefine HAVE_API_TOMTOM 1
#cmakedefine HAVE_GLIB 1
#cmakedefine HAVE_GMODULE 1
#cmakedefine HAVE_GETCWD 1
#define CACHE_SIZE ${CACHE_SIZE}
#cmakedefine AVOID_FLOAT 1
#cmakedefine AVOID_UNALIGNED 1
#cmakedefine USE_LIBGNUINTL 1
#cmakedefine HAVE_BYTESWAP_H 1
/* Versions */
#cmakedefine PACKAGE_VERSION "@PACKAGE_VERSION@"
#cmakedefine PACKAGE_NAME "@PACKAGE_NAME@"
#cmakedefine PACKAGE "@PACKAGE@"
#cmakedefine LOCALEDIR "@LOCALEDIR@"

#cmakedefine HAVE_ZLIB 1

#cmakedefine USE_ROUTING 1

#cmakedefine HAVE_GTK2 1

#cmakedefine HAVE_FONTCONFIG 1

#cmakedefine USE_PLUGINS 1

#cmakedefine SDL_TTF 1

#cmakedefine SDL_IMAGE 1

#cmakedefine HAVE_QT_SVG 1

#cmakedefine HAVE_UNISTD_H 1

#cmakedefine DBUS_USE_SYSTEM_BUS 1

#cmakedefine HAVE_SOCKET 1
#cmakedefine HAVE_SNPRINTF 1
#cmakedefine HAVE_DECL__SNPRINTF 1

#cmakedefine HAVE_WINSOCK 1

#cmakedefine HAVE_MEMALIGN 1

#cmakedefine HAVE_POSIX_MEMALIGN 1

#cmakedefine HAVE_VALLOC 1

#cmakedefine HAVE_LC_MESSAGES 1

#cmakedefine HAVE_SYS_TIME_H 1

#cmakedefine HAVE_POPEN 1

#cmakedefine HAVE_GETOPT_H 1
#cmakedefine HAVE_GETTIMEOFDAY 1

#cmakedefine HAVE__ATOI64 1

#cmakedefine HAVE_STRING_H 1

#cmakedefine EZXML_NOMMAP 0

#cmakedefine HAVE_STPCPY 1

#cmakedefine HAVE_SBRK 1

#cmakedefine HAVE_PRAGMA_PACK 1

#cmakedefine HAVE_GETDELIM 1

#cmakedefine HAVE_GETLINE 1

#cmakedefine HAVE_FSYNC 1

#cmakedefine HAVE_ENDIAN_H 1

#cmakedefine HAVE_FREEIMAGE 1

#cmakedefine USE_OPENGLES 1

#cmakedefine USE_OPENGLES2 1

#cmakedefine HAVE_SHMEM 1

#cmakedefine HAVE_IMLIB2 1

#cmakedefine HAS_IFADDRS 1

#cmakedefine HAVE_POSTGRESQL 1
